From a3007dbcaaffe840ffe400a03cf5358dd65b15f5 Mon Sep 17 00:00:00 2001
From: Lars Bilke <lars.bilke@ufz.de>
Date: Wed, 13 Dec 2023 18:25:22 +0100
Subject: [PATCH] [ogs] Add pkg-config for PETSc finding.

---
 ogscm/recipes/ogs.py | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/ogscm/recipes/ogs.py b/ogscm/recipes/ogs.py
index 1293bb3..df72aaa 100644
--- a/ogscm/recipes/ogs.py
+++ b/ogscm/recipes/ogs.py
@@ -620,8 +620,9 @@ if local_args.mfront and local_args.pm == "system":
     Stage1 += tfel_env
     cmake_args.append("-DOGS_USE_MFRONT=ON")
 
-# Used to fix RPATH in petsc.so build as external dependency
-Stage0 += packages(ospackages=["patchelf"])
+# patchelf used to fix RPATH in petsc.so build as external dependency
+# pkg-config for PETSc finding
+Stage0 += packages(ospackages=["patchelf", "pkg-config"])
 
 if local_args.ccache:
     Stage0 += ccache(cache_size="15G")
-- 
GitLab